@@ -69,7 +69,9 @@ class XNetOptionParser(optparse.OptionParser):
         self.add_option('-T', '--supress-timeout', dest='supress_timeout',
                         help='supress messages from tasks timing out', action='store_true')
         self.add_option('-f', '--format', dest='format', metavar='fmt',
-                        help='specify output format manually, use {v0}, {v1},.. as placeholders')
+                        help='specify output format, see --format-help for info')
+        self.add_option('', '--format-help', dest='format_help', action='store_true',
+                        help='print output format help')
         self.add_option('', '--split-output', dest='split_output', metavar='base',
                         help='produce one output file for each piece of input')
         self.add_option('', '--split-tee', dest='split_tee', metavar='base',
@@ -226,6 +228,10 @@ def _run(ToolImplementation, stdin_data_arg, tool_reads_stdin):
     # main loop
     #
 
+    if opt.format_help:
+        print ToolImplementation.__format_help__()
+        sys.exit(0)
+
     pool = gevent.pool.Pool(_parallelism)
     actions = []  # all spawned actions
     greenlets = []
