@@ -26,8 +26,9 @@ class TcpStateTool(Tool):
             (such as address resolution errors).
     '''
 
-    __description__ = 'test if TCP-ports are open'
+    __toolname__ = 'tcpstate'
     __itemname__ = 'host'
+    __description__ = 'test if TCP-ports are open'
 
     cmdline_options = [
         ('-p', '--port', 'port to state check',
@@ -79,17 +80,17 @@ class TcpStateTool(Tool):
                 state = 'filtered'
             else:
                 state = errmsg.replace(' ', '-').replace(',', '-')
-        except gevent.GreenletExit:
-            #
-            # happens in BT, not OSX
-            #
-            state = 'filtered'
+        #except gevent.GreenletExit:
+        #    #
+        #    # happens in BT, not OSX
+        #    #
+        #    state = 'filtered'
         finally:
             if s:
                 s.close()
-        result['v0'] = result['host'] = addr[0]
-        result['v1'] = result['port'] = addr[1]
-        result['v2'] = result['state'] = state
+        result['host'] = addr[0]
+        result['port'] = addr[1]
+        result['state'] = state
         return result
 
     def __format__(self, line, parse_result, action_result):
@@ -102,10 +103,24 @@ class TcpStateTool(Tool):
             )
         return output
 
+    @classmethod
+    def __format_help__(cls):
+        output = '''
+Format variables for %s:
+
+ host    - target host
+ port    - target port
+ state   - TCP-state or error-message
+
+Default format:
+ '{host} {port} {state}'
+        ''' % cls.__toolname__
+        return output
+
     def __timeout__(self):
         if hasattr(self, '_addr'):
             host, port = self._addr
-            return '{0} {1} filtered\n'.format(host, port)
+            return '{0} {1} timeout\n'.format(host, port)
         return None
 
 
