@@ -21,8 +21,9 @@ class WebgetException(Exception):
 
 class WebgetTool(Tool):
 
-    __description__ = 'get information from web services'
+    __toolname__ = 'webget'
     __itemname__ = 'url'
+    __description__ = 'get information from web services'
 
     cmdline_options = [
         ('-s', '--server', 'print server header',
@@ -89,6 +90,9 @@ class WebgetTool(Tool):
             #request.set_proxy(self.options.proxy, 'https')
 
         read_response = not self.options.code and not self.options.server
+        if self.options.format and '{body}' in self.options.format:
+            read_response = True
+
         try:
             _response = urllib2.urlopen(request)
             self._register_cleanup(lambda: _response.close())
@@ -115,12 +119,12 @@ class WebgetTool(Tool):
                 _response.close()
             except:
                 pass
-        result['v0'] = result['host'] = _host
-        result['v1'] = result['url'] = _url
-        result['v2'] = result['response'] = _response
-        result['v3'] = result['code'] = _code
-        result['v4'] = result['msg'] = _msg
-        result['v5'] = result['body'] = _body
+        result['host'] = _host
+        result['url'] = _url
+        result['response'] = _response
+        result['code'] = _code
+        result['msg'] = _msg
+        result['body'] = _body
         return result
 
     def __format__(self, line, parse_result, value):
@@ -143,6 +147,21 @@ class WebgetTool(Tool):
             output = value['body']
         return output
 
+    @classmethod
+    def __format_help__(cls):
+        output = '''
+Format variables for %s:
+
+ host     - target host
+ url      - target URL
+ code     - status code
+ msg      - status message
+ body     - response body
+
+Default format depend on commandline arguments.
+        ''' % cls.__toolname__
+        return output
+
 
 def main():
     import xnet.tools
